/*
 *  Copyright (C) 2006  UCOT
 *
 *  Distributed under the terms of the MIT License.
 *  See "LICENCE" or http://www.opensource.org/licenses/mit-license.php for details.
 */
package ucot.input;

import java.io.File;
import java.io.FileNotFoundException;
import java.net.URL;
import java.util.Vector;

import ucot.core.Core;

/**
 * <p>
 * Contains input handlers.
 * </p>
 * 
 * @author UCOT
 */
public class InputCollection {

    private Vector<InputInterface> inputs = new Vector<InputInterface>();

    /**
     * <p>
     * Creates input collection.
     * </p>
     */
    public InputCollection() {
    }

    /**
     * <p>
     * Adds given input handler to the collection.
     * </p>
     * 
     * @param inf
     */
    public void add(InputInterface inf) {
        if (!inputs.contains(inf)) inputs.add(inf);
    }

    /**
     * <p>
     * Returns input that can read file on given url
     * </p>
     * 
     * @param url
     *            of the file we want to read
     * @return InputInterface that can read file or null if
     *         none can
     */
    public InputInterface getInputForUrl(URL url)
            throws FileNotFoundException {
        if (url == null) return new DummyInput();

        // Check that the file actually exists before trying
        // InputAdapters
        File file = new File(url.getFile());
        if (!file.exists()) { throw new FileNotFoundException(
                Core.getFileNotFoundMessage(url)); }

        for (int i = 0; i < getInputCount(); i++) {
            if (getInput(i).canRead(url)) return getInput(i);
        }
        return new DummyInput();
    }

    /**
     * @return How many different handlers there are.
     */
    public int getInputCount() {
        return inputs.size();
    }

    /**
     * <p>
     * Returns handler by its index
     * </p>
     * 
     * @param index
     *            Index of the wanted handler.
     * @return The handler at that index.
     */
    public InputInterface getInput(int index) {
        return inputs.get(index);
    }
}
