/*
 *  Copyright (C) 2006  UCOT
 *
 *  Distributed under the terms of the MIT License.
 *  See "LICENCE" or http://www.opensource.org/licenses/mit-license.php for details.
 */
package ucot.output;

import java.io.IOException;
import java.net.URL;

import ucot.ModulePropertyInterface;
import ucot.model.AnalyzeModel;

/**
 * Interface for outputs used by UCOT. Outputs store
 * analyzemodel to a given url. Each Output component stores
 * analyze model in a different way/format.
 * 
 * @author vevijopi
 * 
 */
public interface OutputInterface extends
        ModulePropertyInterface {
    /**
     * Outputs analyze model.
     * 
     * @param analyzeModel
     *            Analyze model to output.
     */
    public void output(AnalyzeModel analyzeModel, URL url)
            throws IOException;

    /**
     * Returns adapter's name.
     * 
     * @return Adapter's name.
     */
    public String getName();

    /**
     * Returns the output's valid file extension without the
     * leading dot.
     * 
     * @return Adapter's accepted file extension.
     */
    public String getFileExtension();

}
