/*
 *  Copyright (C) 2006  UCOT
 *
 *  Distributed under the terms of the MIT License.
 *  See "LICENCE" or http://www.opensource.org/licenses/mit-license.php for details.
 */
package ucot.parser;

import ucot.ModulePropertyInterface;
import ucot.input.UseCase;

/**
 * Interface for parsers within this program. Parsers are
 * given usecase and they return ParsedData
 */
public interface ParserInterface extends
        ModulePropertyInterface {

    public static final String NOUN = "noun";

    public static final String VERB = "verb";

    public static final String SUBJECT = "subject";

    public static final String OBJECT = "object";

    /**
     * Parses given usecase and returns parsed data as a
     * ParsedData object.
     * 
     * @param useCase
     *            Use case to parse.
     * @return Parsed data as a ParsedData object.
     */
    public ParsedData parse(UseCase useCase)
            throws Exception;

    /**
     * Returns adapter's name.
     * 
     * @return Adapter's name.
     */
    public String getName();

}
