/*
 *  Copyright (C) 2006  UCOT
 *
 *  Distributed under the terms of the MIT License.
 *  See "LICENCE" or http://www.opensource.org/licenses/mit-license.php for details.
 */
package ucot.parser;

import java.util.List;
import java.util.Vector;

/**
 * Contains information and words of one sentence. Sentence
 * is builded from a list of words and words cary informaton
 * about their part in the sentence and what part of the
 * speech they represents etc.
 * 
 * @author panu
 * 
 */
public class Sentence {

    private List<Word> words;

    public Sentence() {
        this.words = new Vector<Word>();
    }

    /**
     * <p>
     * Adds the given <code>Word</code> into this
     * <code>Sentence</code>.
     * </p>
     * 
     * @param word
     *            <code>Word</code> to add.
     */
    public void addWord(Word word) {
        words.add(word);
    }

    /**
     * <p>
     * Returns all <code>Word</code>s held by this
     * <code>Sentence</code> in a <code>List</code>.
     * </p>
     * 
     * @return <code>List</code> of <code>Word</code>s
     *         of this <code>Sentence</code>.
     */
    public List<Word> getWords() {
        List<Word> ret = new Vector<Word>();
        ret.addAll(words);
        return ret;

    }

    /**
     * <p>
     * Returns textual representation of this
     * <code>Sentence</code>.
     * </p>
     * <p>
     * The <code>String</code> returned looks like:
     * 
     * <pre>
     *  {SENTENCE: (word 1)(word 2)(word 3)...}
     * </pre>
     * 
     * </p>
     */
    public String toString() {
        StringBuffer buffer = new StringBuffer();
        buffer.append("{SENTENCE: ");
        for (Word word : words) {
            buffer.append("(");
            buffer.append(word);
            buffer.append(") ");
        }
        buffer.append("}");
        return buffer.toString();
    }

}
