/*
 *  Copyright (C) 2006  UCOT
 *
 *  Distributed under the terms of the MIT License.
 *  See "LICENCE" or http://www.opensource.org/licenses/mit-license.php for details.
 */
package ucot.ui.gui.dialog.entitytab;

import javax.swing.JComponent;

import ucot.Messages;
import ucot.model.AnalyzeModel;

/**
 * <p>
 * This class represents interface for general entity's
 * properties modification component. When the
 * <code>EntityPropertiesEditor</code> is created it can
 * be used to show the information of the wanted entity
 * using <code>load</code> method. After the user
 * interaction is done, for example "OK" is pressed in some
 * upeprlevel dialog, the
 * <code>EntityPropertiesEditor</code> can be asked to
 * save the modifications user did using <code>save</code>
 * method.
 * </p>
 * 
 */
public interface EntityPropertiesEditor {

    /**
     * Self pointer string. This string is used to when we
     * need to represent relation that points to the entity
     * beign edited.
     */
    public final static String SELF_POINTER_NAME = Messages
            .getString("SELF_POINTER_NAME");

    /**
     * <p>
     * Clears the panel.
     * </p>
     */
    public void clear();

    /**
     * <p>
     * Loads information to the panel and shows it. This
     * does not clear the view. It only adds the information
     * to the view. Use <code>clear</code> to clear the
     * view.
     * </p>
     * 
     * @param model
     *            The <code>AnalyzeModel</code> which
     *            contains the entity.
     * @param entityName
     *            The name of the entity.
     * @see #clear()
     */
    public void load(AnalyzeModel model, String entityName);

    /**
     * <p>
     * Informs the panel that it should update the given
     * model based on the panel's information. Nothing
     * should happen if <code>save</code> is called after
     * <code>load</code> without user interaction in the
     * panel (or some modifications done in the model).
     * </p>
     * 
     * @param model
     *            The <code>AnalyzeModel</code> which
     *            contains the entity.
     * @param entityName
     *            The name of the entity.
     */
    public void save(AnalyzeModel model, String entityName);

    /**
     * <p>
     * Returns the table name that should be printed in the
     * tab selection menu.
     * </p>
     * 
     * @return table name
     */
    public String getTabName();

    /**
     * <p>
     * Returns the component to be shown to the user to
     * allow editions.
     * </p>
     * 
     * @return The component for this tab.
     */
    public JComponent getComponent();
}
