/*
 *  Copyright (C) 2006  UCOT
 *
 *  Distributed under the terms of the MIT License.
 *  See "LICENCE" or http://www.opensource.org/licenses/mit-license.php for details.
 */
package ucot.ui.gui.tree.usecasetree;

import java.util.List;
import java.util.Vector;

import javax.swing.Icon;

import ucot.input.UseCase;
import ucot.input.UseCaseStep;

/**
 * <p>
 * <code>TreeItem</code> to contain single
 * <code>UseCase</code>.
 * </p>
 * 
 * @author ilanliuk
 * 
 */
public class UseCaseTreeItem extends TreeItem {

    private UseCase usecase;

    /**
     * <p>
     * Default constructor for <code>UseCaseTreeItem</code>.
     * </p>
     * 
     * @param treemodel
     *            <code>UseCaseTreeModel</code> that uses
     *            this <code>TreeItem</code>.
     * @param parent
     *            Parent <code>TreeItem</code> of this
     *            <code>TreeItem</code>.
     * @param usecase
     *            <code>UseCase</code> this
     *            <code>UseCaseTreeItem</code> should
     *            contain.
     */
    public UseCaseTreeItem(UseCaseTreeModel treemodel,
            TreeItem parent, UseCase usecase) {
        super(treemodel, parent);
        this.usecase = usecase;
    }

    @Override
    public String getName() {
        return this.usecase.getName();
    }

    /**
     * <p>
     * Returns is <code>UseCase</code> this
     * <code>UseCaseTreeItem</code> contains in
     * analyzemodel.
     * </p>
     * 
     * @return is <code>UseCase</code> this
     *         <code>UseCaseTreeItem</code> contains in
     *         analyzemodel.
     */
    public boolean isUsecaseInAnalyzemodel() {
        return this.usecase.isUseCaseAnalyzed();
    }

    /**
     * <p>
     * Return <code>UseCase</code> this
     * <code>UseCaseTreeItem</code> contains.
     * </p>
     * 
     * @return <code>UseCase</code> this
     *         <code>UseCaseTreeItem</code> contains.
     */
    public UseCase getUseCase() {
        return this.usecase;
    }

    /*
     * (non-Javadoc)
     * 
     * @see ucot.ui.gui.tree.usecasetree.TreeItem#getChildren()
     */
    @SuppressWarnings(value = { "unchecked" } // Suprreess
                                                // type
                                                // safty
    // warnings.
    )
    @Override
    public List getChildren() {
        List<UseCaseTreeItem> list = new Vector<UseCaseTreeItem>();
        Vector<UseCase> subUseCases = new Vector<UseCase>();
        for (int i = 0; i < this.usecase.getStepCount(); i++) {
            UseCaseStep step = this.usecase.getStep(i);

            UseCase subUseCase = step.getSubUseCase();

            if (subUseCase != null) {
                if (!subUseCases.contains(subUseCase)) {
                    list.add(new UseCaseTreeItem(
                            this.treemodel, this,
                            subUseCase));
                    subUseCases.add(subUseCase);
                }
            }
        }
        return list;
    }

    /*
     * (non-Javadoc)
     * 
     * @see ucot.ui.gui.tree.usecasetree.TreeItem#getIcon()
     */
    @Override
    public Icon getIcon() {

        // if this UseCaseTreeItem is leaf-node
        // check if contained usecase is in model
        // and return correct icon for this.
        if (this.isLeaf()) {
            if (this.isUsecaseInAnalyzemodel()) {
                return UseCaseTree.usecaseLeafIcon;
            } else {
                return UseCaseTree.usecaseLeafIconNotInModel;
            }

        } else {
            // if this UseCaseTreeItem is not leaf-node
            // check if contained usecase is in model
            // and return correct Icon for this.
            if (this.isUsecaseInAnalyzemodel()) {
                return UseCaseTree.usecaseIcon;
            } else {
                return UseCaseTree.usecaseIconNotInModel;
            }

        }
    }
}
